@@ -1,14 +1,13 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Standard S3-methods for "epidataCS" objects, which represent
 ### CONTINUOUS SPATIO-temporal infectious disease case data
 ###
-### Copyright (C) 2009-2015,2017-2019 Sebastian Meyer
-### $Revision: 2505 $
-### $Date: 2019-11-29 15:39:58 +0100 (Fri, 29. Nov 2019) $
+### Copyright (C) 2009-2015,2017-2019,2024 Sebastian Meyer
+### (except where otherwise noted)
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 
@@ -17,13 +16,37 @@
 nobs.epidataCS <- function (object, ...) length(object$events)
 
 
-### UPDATE eps.s, eps.t, qmatrix OR nCircle2Poly IN AN EXISTING epidataCS OBJECT
-
+### UPDATE
 # all arguments but 'object' are optional, the ... argument is unused
-update.epidataCS <- function (object, eps.t, eps.s, qmatrix, nCircle2Poly, ...)
+
+update.epidataCS <- function (object, eps.t, eps.s, qmatrix, nCircle2Poly,
+                              stgrid, ...)
 {
     nEvents <- nobs(object)
 
+    # Update spatio-temporal grid data
+    if (!missing(stgrid)) {
+        oldT <- tail(object$stgrid$stop, 1L)
+        if (inherits(stgrid, "SpatialPolygons"))
+            stgrid <- tiles2stgrid(stgrid, start = 0, T = oldT)
+        stgrid <- check_stgrid(stgrid, T = oldT,
+                               verbose = FALSE, warn = FALSE)
+        ## cannot update tiles because events are linked to these
+        stopifnot(identical(levels(stgrid$tile), levels(object$stgrid$tile)))
+        nTiles <- nlevels(object$stgrid$tile)
+        if ((oldA <- sum(head(object$stgrid$area, nTiles))) !=
+            (newA <- sum(head(       stgrid$area, nTiles))))
+            warning("total tile area has changed: ", paste(oldA, "->", newA))
+        ## merge new spatio-temporal grid data into events@data
+        object$events@data <- cbind(
+            merge_stgrid(marks(object, coords = FALSE),
+                         stgrid, # possibly with dropped/added endemic vars
+                         verbose = FALSE),
+            object$events@data[dotNames_events]
+        )
+        object$stgrid <- stgrid
+    }
+    
     # Check and update eps.t
     if (!missing(eps.t)) {
         stopifnot(is.numeric(eps.t), eps.t > 0)
@@ -62,13 +85,13 @@ update.epidataCS <- function (object, eps.t, eps.s, qmatrix, nCircle2Poly, ...)
     }
 
     # Check qmatrix
-    if (!missing(qmatrix)) object$qmatrix <- checkQ(qmatrix, levels(object$events$type))
+    if (!missing(qmatrix))
+        object$qmatrix <- checkQ(qmatrix, levels(object$events$type))
 
-    #hoehle @ 16 Apr 2011 - bug fix. .obsInfLength was not handled
     # Update length of infection time, i.e. length = min(T-time, eps.t)
-    if (!missing(eps.t)) {
-      timeRange <- with(object$stgrid, c(start[1], stop[length(stop)]))
-      object$events$.obsInfLength <- with(object$events@data, pmin(timeRange[2]-time, eps.t))
+    if (!missing(eps.t) || !missing(stgrid)) {
+        ..T <- tail(object$stgrid$stop, 1L)
+        object$events$.obsInfLength <- with(object$events@data, pmin(..T - time, eps.t))
     }
 
     # Update .sources
@@ -130,14 +153,14 @@ update.epidataCS <- function (object, eps.t, eps.s, qmatrix, nCircle2Poly, ...)
 }
 
 
-## The subset method for epidataCS-objects is adapted from
-## base::subset.data.frame (authored by Peter
-## Dalgaard and Brian Ripley, Copyright (C) 1995-2012
-## The R Core Team) with slight modifications only
-## (we just replace 'x' by 'x$events@data' for evaluation of subset and select)
+## The subset method for "epidataCS" objects is adapted from
+## base::subset.data.frame
+## Copyright (C) 1995-2023 The R Core Team
+## [replaced 'x' by 'x$events@data' when evaluating 'subset' and 'select']
 
 subset.epidataCS <- function (x, subset, select, drop = TRUE, ...)
 {
+    chkDots(...)
     if (missing(subset))
         r <- TRUE
     else {
@@ -157,9 +180,10 @@ subset.epidataCS <- function (x, subset, select, drop = TRUE, ...)
 }
 
 
-## Subset epidataCS object using head and tail methods (which use [.epidataCS)
-## adapted from the corresponding matrix-methods, which have
+## Subset an "epidataCS" object via head() and tail() using [.epidataCS
+## Code adapted from earlier versions of the matrix-specific methods
 ## Copyright (C) 1995-2012 The R Core Team
+## [amended stopifnot(), replaced nrow() by nobs(), omitted 'addrownums']
 
 head.epidataCS <- function (x, n = 6L, ...)
 {
@@ -275,7 +299,7 @@ permute.epidataCS <- function (x, what = c("time", "space"), keep)
 
 print.epidataCS <- function (x, n = 6L, digits = getOption("digits"), ...)
 {
-    print.epidataCS_header(
+    print_epidataCS_header(
         timeRange = c(x$stgrid$start[1L], x$stgrid$stop[nrow(x$stgrid)]),
         bbox = bbox(x$W),
         nBlocks = length(unique(x$stgrid$BLOCK)),
@@ -304,7 +328,7 @@ print.epidataCS <- function (x, n = 6L, digits = getOption("digits"), ...)
     invisible(x)
 }
 
-print.epidataCS_header <- function (timeRange, bbox, nBlocks, nTiles,
+print_epidataCS_header <- function (timeRange, bbox, nBlocks, nTiles,
                                     digits = getOption("digits"))
 {
     bboxtxt <- paste(
@@ -354,7 +378,7 @@ summary.epidataCS <- function (object, ...)
 
 print.summary.epidataCS <- function (x, ...)
 {
-    print.epidataCS_header(timeRange = x$timeRange, bbox = x$bbox,
+    print_epidataCS_header(timeRange = x$timeRange, bbox = x$bbox,
                            nBlocks = x$nBlocks, nTiles = length(x$tileTable))
     cat("Overall number of events: ", x$nEvents, " (",
         if (x$nTypes==1) "single type" else paste(x$nTypes, "types"),
