@@ -59,7 +59,7 @@ lines(c(1:nrow(s.far)-0.5,nrow(s.far)+0.5),c(s.far@control$pd[,2],s.far@control$
 text(nrow(s.far)+2,tail(observed(s.far),n=1),expression(hat(mu)[t[0]]))
 
 
-alarmDates <- epoch(s.far[alarms(s.far) == 1,])
+alarmDates <- epoch(s.far)[alarms(s.far) == 1]
 
 
 par(mar=c(4,4,2,2))
@@ -100,7 +100,7 @@ kappa <- 1.2
 s.nb <- glrnb(momo[,"[75,85)"], control=list(range=phase2,alpha=1/m$theta,mu0=mu0,c.ARL=4.75,theta=log(kappa),ret="cases"))
 
 
-alarmDates <- epoch(s.nb[alarms(s.nb) == 1,])
+alarmDates <- epoch(s.nb)[alarms(s.nb) == 1]
 
 
 plot(s.nb,dx.upperbound=0,legend.opts=NULL,ylab="No. of deaths",main="",ylim=c(0,max(observed(s.nb))*1.1),xlab="time (weeks)",col=c("darkgray",NA,1),lwd=c(1,1,2),lty=c(1,1,1),alarm.symbol=list(pch=24,col=1, cex=1))
@@ -129,13 +129,13 @@ nSims <- 10 #1000
 simone.TAleq65 <- function(sts, g) {
   observed(sts)[phase2,] <- rnbinom(length(mu0), mu=mu0, size=m$theta)
   one <- glrnb(sts, control=modifyList(control(s.nb), list(c.ARL=g)))
-  return(any(alarms(one)))
+  return(any(alarms(one) > 0))
 }
 
 #Determine run-length using 1000 Monte Carlo samples
 g.grid <- seq(1,8,by=0.5)
-pMC <- sapply(g.grid, function(g) { 
-  mean(replicate(nSims, simone.TAleq65(momo[,"[75,85)"],g))) 
+pMC <- sapply(g.grid, function(g) {
+  mean(replicate(nSims, simone.TAleq65(momo[,"[75,85)"],g)))
 })
 
 
@@ -190,7 +190,7 @@ res.far <- replicate(nSims, simone.TAleq65.far(momo[,"[0,1)"],alpha=0.01,mu0=mu0
 #Run CUSUM
 kappa <- 1.2
 s.nb.01 <- glrnb(momo[,"[0,1)"], control=list(range=phase2,alpha=1/m.01$theta,mu0=mu0.far,c.ARL=2.1,theta=log(kappa),ret="cases"))
-alarmDates <- epoch(s.nb.01[alarms(s.nb.01) == 1,])
+alarmDates <- epoch(s.nb.01)[alarms(s.nb.01) == 1]
 
 mu1 <- kappa*mu0.far
 #Show as usual
@@ -199,7 +199,3 @@ lines(1:(nrow(s.far)+1)-0.5, c(mu0.far,tail(mu0.far,n=1)),lwd=3,col=1,lty=1,type
 lines(1:(nrow(s.far)+1)-0.5, c(mu1,tail(mu1,n=1)),col=1,lty=3,lwd=3,type="s")
 legend(x="topright",c(expression(mu[0,t]),expression(mu[1,t]),"NNBA"),col=c(1,1,1),lty=c(1,3,1),horiz=TRUE,bg="white",lwd=c(3,3,1))
 
-
-## demo(biosurvbook)
-
-
