@@ -19,6 +19,8 @@
 
 ##M use old RNGversion to reproduce published simulation results in Section 3.4
 RNGversion("3.3.3")  # sampling has changed in R 3.6.0
+##M reduce printed precision for less machine-specific output
+options(digits = 5)
 
 ################################################################################
 ## Section 3: Spatio-temporal point pattern of infective events
@@ -160,7 +162,7 @@ plot(imdepi, ylim = c(0, 20), col = c("indianred", "darkblue"),
      xlab = "Time [days]")
 for (i in seq_along(imdsims$eventsList))
     plot(imdsims[[i]], add = TRUE, legend.types = FALSE,
-         col = scales::alpha(c("indianred", "darkblue"), 0.5),
+         col = adjustcolor(c("indianred", "darkblue"), alpha.f = 0.5), ##M no need for scales::alpha()
          subset = !is.na(source),  # exclude events of the prehistory
          cumulative = list(offset = .cumoffset, maxat = 336, axis = FALSE),
          border = NA, density = 0) # no histogram for simulations
@@ -372,7 +374,7 @@ stopifnot(all.equal(measlesPreds1$measlesFit_powerlaw$pred,
                     fitted(measlesFit_powerlaw)[tp[1]:tp[2], ],
                     check.attributes = FALSE))
 
-stopifnot(identical(
+stopifnot(all.equal(  ##M identical() fails on some systems
     measlesFit_powerlaw$loglikelihood,
     -sum(scores(oneStepAhead(measlesFit_powerlaw, tp = 1, type = "final"),
                 which = "logs", individual = TRUE))))
