@@ -14,9 +14,12 @@ counts <- observed(measlesWeserEms)
 map <- measlesWeserEms@map
 populationFrac <- measlesWeserEms@populationFrac
 
-## ----measlesWeserEms_neighbourhood-------------------------------------------------
-weserems_adjmat <- poly2adjmat(map)
-weserems_nbOrder <- nbOrder(weserems_adjmat, maxlag = Inf)
+## ----measlesWeserEms_neighbourhood, eval=FALSE-------------------------------------
+#  weserems_adjmat <- poly2adjmat(map)
+#  weserems_nbOrder <- nbOrder(weserems_adjmat)
+
+## ----echo=FALSE--------------------------------------------------------------------
+weserems_nbOrder <- measlesWeserEms@neighbourhood
 
 ## ----measlesWeserEms_construct-----------------------------------------------------
 measlesWeserEms <- sts(counts, start = c(2001, 1), frequency = 52,
@@ -48,7 +51,7 @@ if (require("ggplot2")) {
 
 ## ----measlesModel_basic------------------------------------------------------------
 measlesModel_basic <- list(
-  end = list(f = addSeason2formula(~1 + t, period = measlesWeserEms@freq),
+  end = list(f = addSeason2formula(~1 + t, period = frequency(measlesWeserEms)),
              offset = population(measlesWeserEms)),
   ar = list(f = ~1),
   ne = list(f = ~1, weights = neighbourhood(measlesWeserEms) == 1),
@@ -203,7 +206,7 @@ plot(measlesFit_ri, type = "maps",
   which = c("epi.own", "epi.neighbours", "endemic"),
   prop = TRUE, labels = list(cex = 0.6))
 
-## ----measlesPreds1-----------------------------------------------------------------
+## ----measlesPreds1, results="hide"-------------------------------------------------
 tp <- c(65, 77)
 models2compare <- paste0("measlesFit_", c("basic", "powerlaw", "ri"))
 measlesPreds1 <- lapply(mget(models2compare), oneStepAhead,
@@ -214,7 +217,7 @@ stopifnot(all.equal(measlesPreds1$measlesFit_powerlaw$pred,
                     fitted(measlesFit_powerlaw)[tp[1]:tp[2],],
                     check.attributes = FALSE))
 
-## ----echo=FALSE--------------------------------------------------------------------
+## ----include=FALSE-----------------------------------------------------------------
 stopifnot(all.equal(
     measlesFit_powerlaw$loglikelihood,
     -sum(scores(oneStepAhead(measlesFit_powerlaw, tp = 1, type = "final"),
@@ -225,7 +228,7 @@ SCORES <- c("logs", "rps", "dss", "ses")
 measlesScores1 <- lapply(measlesPreds1, scores, which = SCORES, individual = TRUE)
 t(sapply(measlesScores1, colMeans, dims = 2))
 
-## ----measlesPreds2, eval=COMPUTE---------------------------------------------------
+## ----measlesPreds2, eval=COMPUTE, results="hide"-----------------------------------
 #  measlesPreds2 <- lapply(mget(models2compare), oneStepAhead,
 #    tp = tp, type = "rolling", which.start = "final")
 
