@@ -1,6 +1,6 @@
 data("imdepi")
 
-test_that("determineSourcesC() yields same result as old implementation", {
+test_that("determineSources() yields same result as old implementation", {
     sources0 <- surveillance:::determineSources.epidataCS(imdepi, method = "R")
     expect_identical(sources0, imdepi$events$.sources)
     sources1 <- surveillance:::determineSources(
