@@ -1,12 +1,5 @@
 ### Spatial interaction functions for twinstim()
 
-## spatstat is no longer suggested, so is unavailable during R CMD check
-if (packageVersion("polyCub") <= "0.7.1")
-    exit_file("need polyCub > 0.7.1 to run these tests")
-
-
-### test bundle
-
 myexpectation <- function (siaf, intrfr, intrderivr, pargrid, type = 1, ...)
 {
     ## check analytical intrfr specification against numerical approximation
@@ -25,7 +18,9 @@ myexpectation <- function (siaf, intrfr, intrderivr, pargrid, type = 1, ...)
             )))
 
     ## check deriv, F, Deriv against numerical approximations
-    checksiafres <- surveillance:::checksiaf(siaf, pargrid, type, ...)
+    suppressMessages(
+        checksiafres <- surveillance:::checksiaf(siaf, pargrid, type, ...)
+    )
     for (i in which(!sapply(checksiafres, is.null)))
         expect_true(unique(attr(checksiafres[[i]], "all.equal")),
                     info = names(checksiafres)[i])
